[Libreoffice-commits] core.git: framework/inc framework/source include/svx qadevOOo/runner qadevOOo/tests UnoControls/source

Andrea Gelmini andrea.gelmini at gelma.net
Mon Feb 9 08:20:34 PST 2015


 UnoControls/source/controls/progressmonitor.cxx      |    4 ++--
 framework/inc/classes/wildcard.hxx                   |    2 +-
 framework/source/services/frame.cxx                  |    4 ++--
 include/svx/svdmrkv.hxx                              |    2 +-
 qadevOOo/runner/base/java_complex.java               |    2 +-
 qadevOOo/tests/java/ifc/container/_XNameReplace.java |    4 ++--
 6 files changed, 9 insertions(+), 9 deletions(-)

New commits:
commit 81cb993127d0e399b1c9888fe4f4655b831593d9
Author: Andrea Gelmini <andrea.gelmini at gelma.net>
Date:   Mon Feb 9 10:45:13 2015 +0100

    Fix of a few typos
    
    Change-Id: Ib2a311f0341d165a8f9d3f7a11ec36378fd69519
    Reviewed-on: https://gerrit.libreoffice.org/14373
    Reviewed-by: Michael Stahl <mstahl at redhat.com>
    Tested-by: Michael Stahl <mstahl at redhat.com>

diff --git a/UnoControls/source/controls/progressmonitor.cxx b/UnoControls/source/controls/progressmonitor.cxx
index df93a69..a2f19c3 100644
--- a/UnoControls/source/controls/progressmonitor.cxx
+++ b/UnoControls/source/controls/progressmonitor.cxx
@@ -862,12 +862,12 @@ IMPL_TextlistItem* ProgressMonitor::impl_searchTopic ( const OUString& rTopic, b
 
         if ( pSearchItem->sTopic == rTopic )
         {
-            // We have found this topic ... return a valid pointer.
+            // We have found this topic... return a valid pointer.
             return pSearchItem;
         }
     }
 
-    // We have'nt found this topic ... return a nonvalid pointer.
+    // We haven't found this topic... return a nonvalid pointer.
     return NULL;
 }
 
diff --git a/framework/inc/classes/wildcard.hxx b/framework/inc/classes/wildcard.hxx
index 758fcae..c2bef27 100644
--- a/framework/inc/classes/wildcard.hxx
+++ b/framework/inc/classes/wildcard.hxx
@@ -28,7 +28,7 @@ namespace framework{
     @short          implement wildcard-mechanism for unicode
     @descr          This class can be used to get information about the matching of a pattern to a given text.
                     It's suitable for 8-Bit- AND 16-Bit-strings!
-    @ATTENTION      This class is'nt threadsafe!
+    @ATTENTION      This class isn't threadsafe!
 
     @devstatus      deprecated
 *//*-*************************************************************************************************************/
diff --git a/include/svx/svdmrkv.hxx b/include/svx/svdmrkv.hxx
index e723a37..78d7e84 100644
--- a/include/svx/svdmrkv.hxx
+++ b/include/svx/svdmrkv.hxx
@@ -463,7 +463,7 @@ public:
 
 
 // - Hit tolarances:
-//   It have to be declared in logical coordinates. So please translate the
+//   It has to be declared in logical coordinates. So please translate the
 //   wanted pixel value with PixelToLogic in Logical values.
 //   Taking as example a logical value of 100:
 //   - For a horizontal hairline (Object with height 0), the generated data is +/-100, i.e.
diff --git a/qadevOOo/runner/base/java_complex.java b/qadevOOo/runner/base/java_complex.java
index b5cafa1..f1f6698 100644
--- a/qadevOOo/runner/base/java_complex.java
+++ b/qadevOOo/runner/base/java_complex.java
@@ -68,7 +68,7 @@ public class java_complex implements TestBase
 //        the concept of the TimeOut depends on runner logs. If the runner log,
 //        for example to start a test method, the timeout was reset. This is not
 //        while the test itself log something like "open document...".
-//        An property of complex test could be that it have only one test method
+//        A property of complex test could be that it has only one test method
 //        which works for several minutes. In this case the TimeOut get not trigger
 //        and the office was killed.
 //        In complex tests just use "ThreadTimeOut" as timeout.
diff --git a/qadevOOo/tests/java/ifc/container/_XNameReplace.java b/qadevOOo/tests/java/ifc/container/_XNameReplace.java
index 1d593a8..c05f7f2 100644
--- a/qadevOOo/tests/java/ifc/container/_XNameReplace.java
+++ b/qadevOOo/tests/java/ifc/container/_XNameReplace.java
@@ -39,7 +39,7 @@ import com.sun.star.uno.UnoRuntime;
 *  <li> <code>'NAMEREPLACE'</code> <b>optional</b>: <code>String</code>
 *    relation which represents element name to be replaced.
 *    Some Objects can't replace the firsr that comes along, i.e.
-*    SwXStyleFamily. It have some pool styles which can't be replaced.
+*    SwXStyleFamily. It has some pool styles which can't be replaced.
 *    So the test need a special object to replace it by name. </li>
 *  <li> <code>'XNameReplaceINDEX'</code> : For internal test
 *   usage. Contains current thread number. </li>
@@ -110,7 +110,7 @@ public class _XNameReplace extends MultiMethodTest {
                                                        XNameAccess.class, oObj);
         oNames = oNameAccess.getElementNames();
         /* Some Objects can't replace the firsr that comes along, i.e.
-           SwXStyleFamily. It have some pool styles which can't be replaced.
+           SwXStyleFamily. It has some pool styles which can't be replaced.
            So the test need a special object to replace it by name.
         */
         log.println("get ObjRelation(\"NAMEREPLACE\")");


More information about the Libreoffice-commits mailing list
diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index 5cdb57e..587a058 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -680,7 +680,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL Frame::getActiveFrame() throw
     @seealso    method getActiveFrame()
 
     @param      "xFrame", reference to new active child. It must be an already existing child!
-    @onerror    An assertion is thrown and element is ignored, if given frame is'nt already a child of us.
+    @onerror    An assertion is thrown and element is ignored, if given frame isn't already a child of us.
 *//*-*****************************************************************************************************/
 void SAL_CALL Frame::setActiveFrame( const css::uno::Reference< css::frame::XFrame >& xFrame ) throw( css::uno::RuntimeException, std::exception )
 {
@@ -702,7 +702,7 @@ void SAL_CALL Frame::setActiveFrame( const css::uno::Reference< css::frame::XFra
     aWriteLock.clear();
     /* UNSAFE AREA --------------------------------------------------------------------------------------------- */
 
     // Don't work, if "new" active frame is'nt different from current one!
     // (xFrame==NULL is allowed to UNSET it!)
     if( xActiveChild != xFrame )
     {
@@ -702,7 +702,7 @@ void SAL_CALL Frame::setActiveFrame( const css::uno::Reference< css::frame::XFra
     /* UNSAFE AREA --------------------------------------------------------------------------------------------- */
 
-    // Don't work, if "new" active frame is'nt different from current one!
+    // Don't work, if "new" active frame isn't different from current one!
     // (xFrame==NULL is allowed to UNSET it!)
     if( xActiveChild != xFrame )